# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V28
2507
2509
2891
2892
3018
3021
3402
3405
3548
3549
3550
3551
6080
6081
6084
6086
6976
6978
70475
70477
70844
70845
70846
70847
71098
71099
71992
71993
END
