# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V42
36
37
162
166
1423
1424
1547
1548
2046
2048
2546
2548
2555
2556
2801
2802
3065
3066
3647
3648
6107
6108
8352
8385
43064
43065
65020
65021
65129
65130
65284
65285
65504
65506
65509
65511
73693
73697
123647
123648
126128
126129
END
