# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'ToNt'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'ToNt'}{'missing'} = 'None';

return <<'END';
30	39	Decimal
B2	B3	Digit
B9		Digit
BC	BE	Numeric
660	669	Decimal
6F0	6F9	Decimal
7C0	7C9	Decimal
966	96F	Decimal
9E6	9EF	Decimal
9F4	9F9	Numeric
A66	A6F	Decimal
AE6	AEF	Decimal
B66	B6F	Decimal
B72	B77	Numeric
BE6	BEF	Decimal
BF0	BF2	Numeric
C66	C6F	Decimal
C78	C7E	Numeric
CE6	CEF	Decimal
D58	D5E	Numeric
D66	D6F	Decimal
D70	D78	Numeric
DE6	DEF	Decimal
E50	E59	Decimal
ED0	ED9	Decimal
F20	F29	Decimal
F2A	F33	Numeric
1040	1049	Decimal
1090	1099	Decimal
1369	1371	Digit
1372	137C	Numeric
16EE	16F0	Numeric
17E0	17E9	Decimal
17F0	17F9	Numeric
1810	1819	Decimal
1946	194F	Decimal
19D0	19D9	Decimal
19DA		Digit
1A80	1A89	Decimal
1A90	1A99	Decimal
1B50	1B59	Decimal
1BB0	1BB9	Decimal
1C40	1C49	Decimal
1C50	1C59	Decimal
2070		Digit
2074	2079	Digit
2080	2089	Digit
2150	2182	Numeric
2185	2189	Numeric
2460	2468	Digit
2469	2473	Numeric
2474	247C	Digit
247D	2487	Numeric
2488	2490	Digit
2491	249B	Numeric
24EA		Digit
24EB	24F4	Numeric
24F5	24FD	Digit
24FE		Numeric
24FF		Digit
2776	277E	Digit
277F		Numeric
2780	2788	Digit
2789		Numeric
278A	2792	Digit
2793		Numeric
2CFD		Numeric
3007		Numeric
3021	3029	Numeric
3038	303A	Numeric
3192	3195	Numeric
3220	3229	Numeric
3248	324F	Numeric
3251	325F	Numeric
3280	3289	Numeric
32B1	32BF	Numeric
3405		Numeric
3483		Numeric
382A		Numeric
3B4D		Numeric
4E00		Numeric
4E03		Numeric
4E07		Numeric
4E09		Numeric
4E5D		Numeric
4E8C		Numeric
4E94		Numeric
4E96		Numeric
4EBF	4EC0	Numeric
4EDF		Numeric
4EE8		Numeric
4F0D		Numeric
4F70		Numeric
5104		Numeric
5146		Numeric
5169		Numeric
516B		Numeric
516D		Numeric
5341		Numeric
5343	5345	Numeric
534C		Numeric
53C1	53C4	Numeric
56DB		Numeric
58F1		Numeric
58F9		Numeric
5E7A		Numeric
5EFE	5EFF	Numeric
5F0C	5F0E	Numeric
5F10		Numeric
62FE		Numeric
634C		Numeric
67D2		Numeric
6F06		Numeric
7396		Numeric
767E		Numeric
8086		Numeric
842C		Numeric
8CAE		Numeric
8CB3		Numeric
8D30		Numeric
9621		Numeric
9646		Numeric
964C		Numeric
9678		Numeric
96F6		Numeric
A620	A629	Decimal
A6E6	A6EF	Numeric
A830	A835	Numeric
A8D0	A8D9	Decimal
A900	A909	Decimal
A9D0	A9D9	Decimal
A9F0	A9F9	Decimal
AA50	AA59	Decimal
ABF0	ABF9	Decimal
F96B		Numeric
F973		Numeric
F978		Numeric
F9B2		Numeric
F9D1		Numeric
F9D3		Numeric
F9FD		Numeric
FF10	FF19	Decimal
10107	10133	Numeric
10140	10178	Numeric
1018A	1018B	Numeric
102E1	102FB	Numeric
10320	10323	Numeric
10341		Numeric
1034A		Numeric
103D1	103D5	Numeric
104A0	104A9	Decimal
10858	1085F	Numeric
10879	1087F	Numeric
108A7	108AF	Numeric
108FB	108FF	Numeric
10916	1091B	Numeric
109BC	109BD	Numeric
109C0	109CF	Numeric
109D2	109FF	Numeric
10A40	10A43	Digit
10A44	10A48	Numeric
10A7D	10A7E	Numeric
10A9D	10A9F	Numeric
10AEB	10AEF	Numeric
10B58	10B5F	Numeric
10B78	10B7F	Numeric
10BA9	10BAF	Numeric
10CFA	10CFF	Numeric
10D30	10D39	Decimal
10E60	10E68	Digit
10E69	10E7E	Numeric
10F1D	10F26	Numeric
10F51	10F54	Numeric
10FC5	10FCB	Numeric
11052	1105A	Digit
1105B	11065	Numeric
11066	1106F	Decimal
110F0	110F9	Decimal
11136	1113F	Decimal
111D0	111D9	Decimal
111E1	111F4	Numeric
112F0	112F9	Decimal
11450	11459	Decimal
114D0	114D9	Decimal
11650	11659	Decimal
116C0	116C9	Decimal
11730	11739	Decimal
1173A	1173B	Numeric
118E0	118E9	Decimal
118EA	118F2	Numeric
11950	11959	Decimal
11C50	11C59	Decimal
11C5A	11C6C	Numeric
11D50	11D59	Decimal
11DA0	11DA9	Decimal
11FC0	11FD4	Numeric
12400	1246E	Numeric
16A60	16A69	Decimal
16AC0	16AC9	Decimal
16B50	16B59	Decimal
16B5B	16B61	Numeric
16E80	16E96	Numeric
1D2E0	1D2F3	Numeric
1D360	1D378	Numeric
1D7CE	1D7FF	Decimal
1E140	1E149	Decimal
1E2F0	1E2F9	Decimal
1E8C7	1E8CF	Numeric
1E950	1E959	Decimal
1EC71	1ECAB	Numeric
1ECAD	1ECAF	Numeric
1ECB1	1ECB4	Numeric
1ED01	1ED2D	Numeric
1ED2F	1ED3D	Numeric
1F100	1F10A	Digit
1F10B	1F10C	Numeric
1FBF0	1FBF9	Decimal
20001		Numeric
20064		Numeric
200E2		Numeric
20121		Numeric
2092A		Numeric
20983		Numeric
2098C		Numeric
2099C		Numeric
20AEA		Numeric
20AFD		Numeric
20B19		Numeric
22390		Numeric
22998		Numeric
23B1B		Numeric
2626D		Numeric
2F890		Numeric
END
